@@ -1,3 +1,4 @@
+import os
 
 from pycret_santa import Separators
 from pycret_santa.config import MailParameters
@@ -5,6 +6,9 @@ from pycret_santa.guests import Guest
 from pycret_santa.mails import BaseMail
 
 
+def getDataPath():
+  return os.path.join(os.path.abspath(os.path.dirname(__file__)))
+
 class TestUtils(object):
 
   NAMES = ["John", "Jack", "Julia"]
